## [:Category:Oxidoreductases](:Category:Oxidoreductases "wikilink") (EC 1) ([Oxidoreductase](Oxidoreductase "wikilink"))

-   [Dehydrogenase](Dehydrogenase "wikilink")
-   [Luciferase](Luciferase "wikilink")
-   [DMSO reductase](DMSO_reductase "wikilink")

### [:Category:EC 1.1](:Category:EC_1.1 "wikilink") (act on the CH-OH group of donors)

-   **[:Category:EC 1.1.1](:Category:EC_1.1.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
    -   [Alcohol dehydrogenase (NAD)](Alcohol_dehydrogenase "wikilink")
    -   [Alcohol dehydrogenase (NADP)](Alcohol_dehydrogenase "wikilink")
    -   [Homoserine dehydrogenase](Homoserine_dehydrogenase "wikilink")
    -   [Aminopropanol oxidoreductase]((R,R)-butanediol_dehydrogenase "wikilink")
    -   [Diacetyl reductase](Diacetyl_reductase "wikilink")
    -   [Glycerol dehydrogenase](Glycerol_dehydrogenase "wikilink")
    -   [Propanediol-phosphate dehydrogenase](Propanediol-phosphate_dehydrogenase "wikilink")
    -   [glycerol-3-phosphate dehydrogenase (NAD+)](glycerol-3-phosphate_dehydrogenase_(NAD+) "wikilink")
    -   [D-xylulose reductase](D-xylulose_reductase "wikilink")
    -   [L-xylulose reductase](L-xylulose_reductase "wikilink")
    -   [Lactate dehydrogenase](Lactate_dehydrogenase "wikilink")
    -   [Malate dehydrogenase](Malate_dehydrogenase "wikilink")
    -   [Isocitrate dehydrogenase](Isocitrate_dehydrogenase "wikilink")
    -   [HMG-CoA reductase](HMG-CoA_reductase "wikilink")
-   **[:Category:EC 1.1.2](:Category:EC_1.1.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.1.3](:Category:EC_1.1.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Glucose oxidase](Glucose_oxidase "wikilink")
    -   [L-gulonolactone oxidase](L-gulonolactone_oxidase "wikilink")
    -   [Thiamine oxidase](Thiamine_oxidase "wikilink")
    -   [Xanthine oxidase](Xanthine_oxidase "wikilink")
-   **[:Category:EC 1.1.4](:Category:EC_1.1.4 "wikilink")** (with a [disulfide](disulfide "wikilink") as acceptor)
-   **[:Category:EC 1.1.5](:Category:EC_1.1.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
-   **[:Category:EC 1.1.99](:Category:EC_1.1.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.2](:Category:EC_1.2 "wikilink") (act on the aldehyde or oxo group of donors)

-   **[:Category:EC 1.2.1](:Category:EC_1.2.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
    -   [Acetaldehyde dehydrogenase](Acetaldehyde_dehydrogenase "wikilink")
    -   [Glyceraldehyde 3-phosphate dehydrogenase](Glyceraldehyde_3-phosphate_dehydrogenase "wikilink")
    -   [Pyruvate dehydrogenase](Pyruvate_dehydrogenase "wikilink")
-   **[:Category:EC 1.2.4](:Category:EC_1.2.4 "wikilink")**
    -   [Oxoglutarate dehydrogenase](Oxoglutarate_dehydrogenase "wikilink")

### [:Category:EC 1.3](:Category:EC_1.3 "wikilink") (act on the CH-CH group of donors)

-   **[:Category:EC 1.3.1](:Category:EC_1.3.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
    -   [Biliverdin reductase](Biliverdin_reductase "wikilink")
-   **[:Category:EC 1.3.2](:Category:EC_1.3.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.3.3](:Category:EC_1.3.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Protoporphyrinogen oxidase](Protoporphyrinogen_oxidase "wikilink")
-   **[:Category:EC 1.3.5](:Category:EC_1.3.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
-   **[:Category:EC 1.3.7](:Category:EC_1.3.7 "wikilink")** (with an [iron-sulfur protein](iron-sulfur_protein "wikilink") as acceptor)
-   **[:Category:EC 1.3.99](:Category:EC_1.3.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.4](:Category:EC_1.4 "wikilink") (act on the CH-NH<sub>2</sub> group of donors)

-   **[:Category:EC 1.4.3](:Category:EC_1.4.3 "wikilink")**
    -   [Monoamine oxidase](Monoamine_oxidase "wikilink")

### [:Category:EC 1.5](:Category:EC_1.5 "wikilink") (act on CH-NH group of donors)

-   **[:Category:EC 1.5.1](:Category:EC_1.5.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
    -   [Dihydrofolate reductase](Dihydrofolate_reductase "wikilink")
    -   [Methylenetetrahydrofolate reductase](Methylenetetrahydrofolate_reductase "wikilink")
-   **[:Category:EC 1.5.3](:Category:EC_1.5.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Sarcosine oxidase](Sarcosine_oxidase "wikilink")
    -   [Dihydrobenzophenanthridine oxidase](Dihydrobenzophenanthridine_oxidase "wikilink")
-   **[:Category:EC 1.5.4](:Category:EC_1.5.4 "wikilink")** (with a [disulfide](disulfide "wikilink") as acceptor)
-   **[:Category:EC 1.5.5](:Category:EC_1.5.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
-   **[:Category:EC 1.5.7](:Category:EC_1.5.7 "wikilink")** (with an [iron-sulfur protein](iron-sulfur_protein "wikilink") as acceptor)
-   **[:Category:EC 1.5.8](:Category:EC_1.5.8 "wikilink")** (with a [flavin](Flavin_group "wikilink") as acceptor)
-   **[:Category:EC 1.5.99](:Category:EC_1.5.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.6](:Category:EC_1.6 "wikilink") (act on NADH or NADPH)

-   **[:Category:EC 1.6.1](:Category:EC_1.6.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
-   **[:Category:EC 1.6.2](:Category:EC_1.6.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.6.3](:Category:EC_1.6.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
-   **Category:EC 1.6.4** now [:Category:EC 1.8.1](:Category:EC_1.8.1 "wikilink")
-   **[:Category:EC 1.6.5](:Category:EC_1.6.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
    -   [NADH dehydrogenase](NADH_dehydrogenase "wikilink")
-   **[:Category:EC 1.6.6](:Category:EC_1.6.6 "wikilink")** (with a [nitrogenous](nitrogen "wikilink") group as acceptor)
-   **Category:EC 1.6.7** now [:Category:EC 1.18.1](:Category:EC_1.18.1 "wikilink")
-   **Category:EC 1.6.8** now [:Category:EC 1.5.1](:Category:EC_1.5.1 "wikilink")
-   **[:Category:EC 1.6.99](:Category:EC_1.6.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.7](:Category:EC_1.7 "wikilink") (act on other nitrogenous compounds as donors)

-   **[:Category:EC 1.7.1](:Category:EC_1.7.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
-   **[:Category:EC 1.7.2](:Category:EC_1.7.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.7.3](:Category:EC_1.7.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Urate oxidase](Urate_oxidase "wikilink")
-   **[:Category:EC 1.7.7](:Category:EC_1.7.7 "wikilink")** (with an [iron-sulfur protein](iron-sulfur_protein "wikilink") as acceptor)
-   **[:Category:EC 1.7.99](:Category:EC_1.7.99 "wikilink")** (with other acceptors)
    -   [Nitrite reductase](Nitrite_reductase "wikilink")
    -   [Nitrate reductase](Nitrate_reductase "wikilink")

### [:Category:EC 1.8](:Category:EC_1.8 "wikilink") (act on a sulfur group of donors)

-   **[:Category:EC 1.8.1](:Category:EC_1.8.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
    -   [Glutathione reductase](Glutathione_reductase "wikilink")
    -   [Thioredoxin reductase](Thioredoxin_reductase "wikilink")
-   **[:Category:EC 1.8.2](:Category:EC_1.8.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.8.3](:Category:EC_1.8.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Sulfite oxidase](Sulfite_oxidase "wikilink")
-   **[:Category:EC 1.8.4](:Category:EC_1.8.4 "wikilink")** (with a [disulfide](disulfide "wikilink") as acceptor)
-   **[:Category:EC 1.8.5](:Category:EC_1.8.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
-   **Category:EC 1.8.6** deleted, included in [EC 2.5.1.18](EC_2.5.1.18 "wikilink")
-   **[:Category:EC 1.8.7](:Category:EC_1.8.7 "wikilink")** (with an [iron-sulfur protein](iron-sulfur_protein "wikilink") as acceptor)
-   **[:Category:EC 1.8.98](:Category:EC_1.8.98 "wikilink")** (with other, known, acceptors)
-   **[:Category:EC 1.8.99](:Category:EC_1.8.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.9](:Category:EC_1.9 "wikilink") (act on a [heme](heme "wikilink") group of donors)

-   **[:Category:EC 1.9.3](:Category:EC_1.9.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Cytochrome c oxidase](Cytochrome_c_oxidase "wikilink")
-   **[:Category:EC 1.9.6](:Category:EC_1.9.6 "wikilink")** (with a [nitrogenous](nitrogen "wikilink") as acceptor)
-   **Category:EC 1.9.99** transferred, now [EC 1.9.98.1](EC_1.9.98.1 "wikilink")

### [:Category:EC 1.10](:Category:EC_1.10 "wikilink") (act on [diphenols](benzenediol "wikilink") and related substances as donors)

-   **[:Category:EC 1.10.1](:Category:EC_1.10.1 "wikilink")**(with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
-   **[:Category:EC 1.10.2](:Category:EC_1.10.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
    -   [Coenzyme Q - cytochrome c reductase](Coenzyme_Q_-_cytochrome_c_reductase "wikilink")
-   **[:Category:EC 1.10.3](:Category:EC_1.10.3 "wikilink")** (with [oxygen](oxygen "wikilink") as acceptor)
    -   [Catechol oxidase](Catechol_oxidase "wikilink")
    -   [Laccase](Laccase "wikilink")
-   **[:Category:EC 1.10.99](:Category:EC_1.10.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.11](:Category:EC_1.11 "wikilink") (act on [peroxide](peroxide "wikilink") as an acceptor -- [peroxidases](peroxidase "wikilink"))

-   **[:Category:EC 1.11.1](:Category:EC_1.11.1 "wikilink")** ([peroxidases](peroxidase "wikilink"))
    -   [Cytochrome c peroxidase](Cytochrome_c_peroxidase "wikilink")
    -   [Catalase](Catalase "wikilink")
    -   [Myeloperoxidase](Myeloperoxidase "wikilink")
    -   [Thyroid peroxidase](Thyroid_peroxidase "wikilink")
    -   [Glutathione peroxidase](Glutathione_peroxidase "wikilink")

### [:Category:EC 1.12](:Category:EC_1.12 "wikilink") (act on hydrogen as a donor)

-   **[:Category:EC 1.12.1](:Category:EC_1.12.1 "wikilink")** (with [NAD<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") or [NADP<sup>+</sup>](Nicotinamide_adenine_dinucleotide "wikilink") as acceptor)
-   **[:Category:EC 1.12.2](:Category:EC_1.12.2 "wikilink")** (with a [cytochrome](cytochrome "wikilink") as acceptor)
-   **[:Category:EC 1.12.5](:Category:EC_1.12.5 "wikilink")** (with a [quinone](quinone "wikilink") or similar compound as acceptor)
-   **[:Category:EC 1.12.7](:Category:EC_1.12.7 "wikilink")** (with an [iron-sulfur protein](iron-sulfur_protein "wikilink") as acceptor)
-   **[:Category:EC 1.12.98](:Category:EC_1.12.98 "wikilink")** (with other known acceptors)
-   **[:Category:EC 1.12.99](:Category:EC_1.12.99 "wikilink")** (with other acceptors)

### [:Category:EC 1.13](:Category:EC_1.13 "wikilink") (act on single donors with incorporation of molecular oxygen)

-   **[:Category:EC 1.13.11](:Category:EC_1.13.11 "wikilink")** (With incorporation of two atoms of oxygen)
    -   [4-hydroxyphenylpyruvate dioxygenase](4-hydroxyphenylpyruvate_dioxygenase "wikilink") ()
-   **[:Category:EC 1.13.12](:Category:EC_1.13.12 "wikilink")** (With incorporation of one atom of oxygen (internal monooxygenases or internal mixed function oxidases))
    -   [Renilla-luciferin 2-monooxygenase](Renilla-luciferin_2-monooxygenase "wikilink")
    -   [Cypridina-luciferin 2-monooxygenase](Cypridina-luciferin_2-monooxygenase "wikilink")
    -   [Firefly luciferase](Firefly_luciferase "wikilink")
    -   [Watasenia-luciferin 2-monooxygenase](Watasenia-luciferin_2-monooxygenase "wikilink")
    -   [Oplophorus-luciferin 2-monooxygenase](Oplophorus-luciferin_2-monooxygenase "wikilink")

### [:Category:EC 1.14](:Category:EC_1.14 "wikilink") (act on paired donors with incorporation of molecular oxygen)

-   [Cytochrome P450 oxidase](Cytochrome_P450_oxidase "wikilink")
-   **[:Category:Cytochrome P450](:Category:Cytochrome_P450 "wikilink")**
    -   [Aromatase](Aromatase "wikilink")
    -   [CYP2D6](CYP2D6 "wikilink")
    -   [CYP2E1](CYP2E1 "wikilink")
    -   [CYP3A4](CYP3A4 "wikilink")
    -   [Cytochrome P450 oxidase](Cytochrome_P450_oxidase "wikilink")
-   **[:Category:EC 1.14.12](:Category:EC_1.14.12 "wikilink")**
    -   [Nitric oxide dioxygenase](Nitric_oxide_dioxygenase "wikilink")
-   **[:Category:EC 1.14.13](:Category:EC_1.14.13 "wikilink")**
    -   [Nitric oxide synthase](Nitric_oxide_synthase "wikilink")
-   **[:Category:EC 1.14.14](:Category:EC_1.14.14 "wikilink")**
    -   [Aromatase](Aromatase "wikilink")
    -   [CYP2D6](CYP2D6 "wikilink")
    -   [CYP2E1](CYP2E1 "wikilink")
    -   [CYP3A4](CYP3A4 "wikilink")
-   **[:Category:EC 1.14.16](:Category:EC_1.14.16 "wikilink")**
    -   [Phenylalanine hydroxylase](Phenylalanine_hydroxylase "wikilink")
-   **[:Category:EC 1.14.18](:Category:EC_1.14.18 "wikilink")**
    -   [Tyrosinase](Tyrosinase "wikilink")

### [:Category:EC 1.15](:Category:EC_1.15 "wikilink") (act on superoxide radicals as acceptors)

-   **[:Category:EC 1.15.1](:Category:EC_1.15.1 "wikilink")**
    -   [Superoxide dismutase](Superoxide_dismutase "wikilink")

### [:Category:EC 1.16](:Category:EC_1.16 "wikilink") (oxidize metal ions)

-   **[:Category:EC 1.16.3](:Category:EC_1.16.3 "wikilink")**
    -   [Ceruloplasmin](Ceruloplasmin "wikilink")

### [:Category:EC 1.17](:Category:EC_1.17 "wikilink") (act on CH or CH<sub>2</sub> groups)

-   **[:Category:EC 1.17.1](:Category:EC_1.17.1 "wikilink")**
    -   [Leucoanthocyanidin reductase](Leucoanthocyanidin_reductase "wikilink")
    -   [Xanthine dehydrogenase](Xanthine_dehydrogenase "wikilink")
    -   [Nicotinate dehydrogenase](Nicotinate_dehydrogenase "wikilink")
    -   [4-hydroxy-tetrahydrodipicolinate reductase](4-hydroxy-tetrahydrodipicolinate_reductase "wikilink")
-   **[:Category:EC 1.17.2](:Category:EC_1.17.2 "wikilink")**
    -   [Nicotinate dehydrogenase (cytochrome)](Nicotinate_dehydrogenase_(cytochrome) "wikilink")
-   **[:Category:EC 1.17.3](:Category:EC_1.17.3 "wikilink")**
    -   [Xanthine oxidase](Xanthine_oxidase "wikilink")
-   **[:Category:EC 1.17.4](:Category:EC_1.17.4 "wikilink")**
    -   [Ribonucleotide reductase](Ribonucleotide_reductase "wikilink")
    -   [Ribonucleoside-triphosphate reductase](Ribonucleoside-triphosphate_reductase "wikilink")
    -   [Vitamin K epoxide reductase](Vitamin_K_epoxide_reductase "wikilink")
    -   [Vitamin-K-epoxide reductase (warfarin-sensitive)](Vitamin-K-epoxide_reductase_(warfarin-sensitive) "wikilink")
    -   [Vitamin-K-epoxide reductase (warfarin-insensitive)](Vitamin-K-epoxide_reductase_(warfarin-insensitive) "wikilink")
    -   [RRM1](RRM1 "wikilink")
    -   [RRM2](RRM2 "wikilink")
    -   [RRM2B](RRM2B "wikilink")
-   **[:Category:EC 1.17.5](:Category:EC_1.17.5 "wikilink")**
    -   [Caffeine dehydrogenase](Caffeine_dehydrogenase "wikilink")
-   **[:Category:EC 1.17.7](:Category:EC_1.17.7 "wikilink")**
-   **[:Category:EC 1.17.99](:Category:EC_1.17.99 "wikilink")**

### [:Category:EC 1.18](:Category:EC_1.18 "wikilink") (act on iron-sulfur proteins as donors)

-   **[:Category:EC 1.18.6](:Category:EC_1.18.6 "wikilink")**
    -   [Nitrogenase](Nitrogenase "wikilink")

### [:Category:EC 1.19](:Category:EC_1.19 "wikilink") (act on reduced flavodoxin as donor)

-   **[:Category:EC 1.19.6](:Category:EC_1.19.6 "wikilink")**
    -   [Nitrogenase (flavodoxin)](Nitrogenase_(flavodoxin) "wikilink")

### [:Category:EC 1.20](:Category:EC_1.20 "wikilink") (act on phosphorus or arsenic as donors)

-   **[:Category:EC 1.20.1](:Category:EC_1.20.1 "wikilink")**
-   **[:Category:EC 1.20.2](:Category:EC_1.20.2 "wikilink")**
-   **[:Category:EC 1.20.4](:Category:EC_1.20.4 "wikilink")**
    -   [Arsenate reductase (glutaredoxin)](Arsenate_reductase_(glutaredoxin) "wikilink")
    -   [Glutaredoxin](Glutaredoxin "wikilink")
-   **[:Category:EC 1.20.9](:Category:EC_1.20.9 "wikilink")**
-   **[:Category:EC 1.20.99](:Category:EC_1.20.99 "wikilink")**

### [:Category:EC 1.21](:Category:EC_1.21 "wikilink") (act on X-H and Y-H to form an X-Y bond)

-   **[:Category:EC 1.21.1](:Category:EC_1.21.1 "wikilink")**
    -   [Iodotyrosine deiodinase](Iodotyrosine_deiodinase "wikilink")
-   **[:Category:EC 1.21.3](:Category:EC_1.21.3 "wikilink")**
    -   [Isopenicillin N synthase](Isopenicillin_N_synthase "wikilink")
    -   [Tetrahydrocannabinolic acid synthase](Tetrahydrocannabinolic_acid_synthase "wikilink")
-   **[:Category:EC 1.21.4](:Category:EC_1.21.4 "wikilink")**
-   **[:Category:EC 1.21.99](:Category:EC_1.21.99 "wikilink")**
    -   [Thyroxine 5-deiodinase](Thyroxine_5-deiodinase "wikilink")
    -   [Iodothyronine deiodinase](Iodothyronine_deiodinase "wikilink") and

### [:Category:EC 1.97](:Category:EC_1.97 "wikilink") (other oxidoreductases)

-   **[:Category:EC 1.97.1](:Category:EC_1.97.1 "wikilink")**
    -   [Deiodinase](Deiodinase "wikilink")

## [:Category:Transferases](:Category:Transferases "wikilink") (EC 2) ([Transferase](Transferase "wikilink"))

-   [Glutathione S-transferase](Glutathione_S-transferase "wikilink")

### [:Category:EC 2.1](:Category:EC_2.1 "wikilink") (transfer one-carbon groups, [Methylase](Methylase "wikilink"))

-   **[:Category:EC 2.1.1](:Category:EC_2.1.1 "wikilink")**
    -   [Catechol-O-methyl transferase](Catechol-O-methyl_transferase "wikilink")
    -   [DNA methyltransferase](DNA_methyltransferase "wikilink") , ,
    -   [Histone methyltransferase](Histone_methyltransferase "wikilink") ,
-   **[:Category:EC 2.1.3](:Category:EC_2.1.3 "wikilink")**
    -   [Aspartate transcarbamoylase](Aspartate_transcarbamoylase "wikilink")
    -   [Ornithine transcarbamoylase](Ornithine_transcarbamoylase "wikilink")

### [:Category:EC 2.2](:Category:EC_2.2 "wikilink") (transfer [aldehyde](aldehyde "wikilink") or [ketone](ketone "wikilink") groups)

-   **[:Category:EC 2.2.1](:Category:EC_2.2.1 "wikilink")**
    -   [Transketolase](Transketolase "wikilink")
    -   [Transaldolase](Transaldolase "wikilink")
    -   [Acetolactate synthase](Acetolactate_synthase "wikilink")
    -   [2-Succinyl-5-enolpyruvyl-6-hydroxy-3-cyclohexene-1-carboxylic-acid synthase](2-Succinyl-5-enolpyruvyl-6-hydroxy-3-cyclohexene-1-carboxylic-acid_synthase "wikilink")

### [:Category:EC 2.3](:Category:EC_2.3 "wikilink") (acyltransferases)

-   **[:Category:EC 2.3.1](:Category:EC_2.3.1 "wikilink")**
    -   [Aminolevulinic acid synthase](Aminolevulinic_acid_synthase "wikilink")
    -   [Choline acetyltransferase](Choline_acetyltransferase "wikilink")
-   **[:Category:EC 2.3.2](:Category:EC_2.3.2 "wikilink")**
    -   [Factor XIII](Factor_XIII "wikilink")
    -   [Gamma glutamyl transpeptidase](Gamma_glutamyl_transpeptidase "wikilink")
    -   [Transglutaminase](Transglutaminase "wikilink")

### [:Category:EC 2.4](:Category:EC_2.4 "wikilink") (glycosyltransferases)

-   **[:Category:EC 2.4.2](:Category:EC_2.4.2 "wikilink")**
    -   [Hypoxanthine-guanine phosphoribosyltransferase](Hypoxanthine-guanine_phosphoribosyltransferase "wikilink")

**[:Category:EC 2.5](:Category:EC_2.5 "wikilink")**

-   **[:Category:EC 2.5.1](:Category:EC_2.5.1 "wikilink")**
    -   [Thiaminase](Thiaminase "wikilink")

### [:Category:EC 2.5](:Category:EC_2.5 "wikilink") (transfer [alkyl](alkyl "wikilink") or [aryl](aryl "wikilink") groups, other than [methyl](methyl "wikilink") groups)

-   -   [Flavin prenyltransferase](Flavin_prenyltransferase "wikilink")

### [:Category:EC 2.6](:Category:EC_2.6 "wikilink") (transfer nitrogenous groups)

-   **[:Category:EC 2.6.1](:Category:EC_2.6.1 "wikilink")**
    -   [Alanine transaminase](Alanine_transaminase "wikilink")
    -   [Aspartate transaminase](Aspartate_transaminase "wikilink")

### [:Category:EC 2.7](:Category:EC_2.7 "wikilink") (transfer phosphorus-containing groups)

-   **[:Category:EC 2.7.2](:Category:EC_2.7.2 "wikilink")**
    -   [Butyrate kinase](Butyrate_kinase "wikilink") ()

### [:Category:EC 2.8](:Category:EC_2.8 "wikilink") (transfer sulfur-containing groups)

-   : [Thiosulfate sulfurtransferase](Thiosulfate_sulfurtransferase "wikilink")

-   : [3-mercaptopyruvate sulfurtransferase](3-mercaptopyruvate_sulfurtransferase "wikilink")

-   : [Thiosulfate--thiol sulfurtransferase](Thiosulfate--thiol_sulfurtransferase "wikilink")

-   : [tRNA uracil 4-sulfurtransferase](tRNA_uracil_4-sulfurtransferase "wikilink")

-   : [Thiosulfate--dithiol sulfurtransferase](Thiosulfate--dithiol_sulfurtransferase "wikilink")

-   : [Biotin synthase](Biotin_synthase "wikilink")

-   : [Cysteine desulfurase](Cysteine_desulfurase "wikilink")

-   : [Lipoyl synthase](Lipoyl_synthase "wikilink")

-   : [Molybdenum cofactor sulfurtransferase](Molybdenum_cofactor_sulfurtransferase "wikilink")

-   : [Thiazole synthase](Thiazole_synthase "wikilink")

-   : [Molybdopterin synthase sulfurtransferase](Molybdopterin_synthase_sulfurtransferase "wikilink")

-   : [Molybdopterin synthase](Molybdopterin_synthase "wikilink")

-   : [tRNA-uridine 2-sulfurtransferase](tRNA-uridine_2-sulfurtransferase "wikilink")

-   : [tRNA-5-taurinomethyluridine 2-sulfurtransferase](tRNA-5-taurinomethyluridine_2-sulfurtransferase "wikilink")

-   : [tRNA-5-methyluridine(54) 2-sulfurtransferase](tRNA-5-methyluridine(54)_2-sulfurtransferase "wikilink")

### [:Category:EC 2.9](:Category:EC_2.9 "wikilink") (transfer selenium-containing groups)

-   : [L-seryl-tRNA(Sec) selenium transferase](L-seryl-tRNA(Sec)_selenium_transferase "wikilink")

-   : [O-phospho-L-seryl-tRNA(Sec):L-selenocysteinyl-tRNA synthase](O-phospho-L-seryl-tRNA(Sec):L-selenocysteinyl-tRNA_synthase "wikilink")

## [:Category:Hydrolases](:Category:Hydrolases "wikilink") (EC 3) ([Hydrolase](Hydrolase "wikilink"))

-   [Hydrolytic enzyme](Hydrolytic_enzyme "wikilink")

### [:Category:EC 3.1](:Category:EC_3.1 "wikilink") (act on [ester](ester "wikilink") bonds)

-   [Nuclease](Nuclease "wikilink")
-   [Endonuclease](Endonuclease "wikilink")
-   [Exonuclease](Exonuclease "wikilink")
-   **[:Category:EC 3.1.1](:Category:EC_3.1.1 "wikilink")**
    -   [Acid hydrolase](Acid_hydrolase "wikilink")
    -   [Phospholipase](Phospholipase "wikilink") A ()
    -   [Acetylcholinesterase](Acetylcholinesterase "wikilink") ()
    -   [Cholinesterase](Cholinesterase "wikilink") ()
    -   [Lipoprotein lipase](Lipoprotein_lipase "wikilink") ()
-   **[:Category:EC 3.1.2](:Category:EC_3.1.2 "wikilink")**
    -   [Ubiquitin carboxy-terminal hydrolase L1](Ubiquitin_carboxy-terminal_hydrolase_L1 "wikilink") ()
-   **[:Category:EC 3.1.3](:Category:EC_3.1.3 "wikilink")**
    -   [Phosphatase](Phosphatase "wikilink")
    -   [Alkaline phosphatase](Alkaline_phosphatase "wikilink") ()
    -   [Fructose bisphosphatase](Fructose_1,6-bisphosphatase "wikilink") ()
-   **[:Category:EC 3.1.4](:Category:EC_3.1.4 "wikilink")**
    -   [Phospholipase](Phospholipase "wikilink") C ()
    -   [CGMP specific phosphodiesterase type 5](CGMP_specific_phosphodiesterase_type_5 "wikilink") ()
    -   [Phospholipase](Phospholipase "wikilink") D ()
-   **[:Category:EC 3.1.21](:Category:EC_3.1.21 "wikilink")**
    -   [Restriction enzyme](Restriction_enzyme "wikilink") Type 1 ()
    -   [Restriction enzyme](Restriction_enzyme "wikilink") Type 2 ()
    -   [Restriction enzyme](Restriction_enzyme "wikilink") Type 3 ()
    -   [Restriction enzyme](Restriction_enzyme "wikilink") Type 4 (?)
    -   [Deoxyribonuclease](Deoxyribonuclease "wikilink") I ()
-   **[:Category:EC 3.1.26](:Category:EC_3.1.26 "wikilink")**
    -   [RNase H](RNase_H "wikilink") ()
-   **[:Category:EC 3.1.27](:Category:EC_3.1.27 "wikilink")**
    -   [Ribonuclease](Ribonuclease "wikilink")

### [:Category:EC 3.2](:Category:EC_3.2 "wikilink") (act on sugars - [glycosylases](glycosylases "wikilink"))

-   **[:Category:EC 3.2.1](:Category:EC_3.2.1 "wikilink")**
    -   [Amylase](Amylase "wikilink") ()
    -   [Sucrase](Sucrase "wikilink") ()
    -   [Chitinase](Chitinase "wikilink") ()
    -   [Lysozyme](Lysozyme "wikilink") ()
    -   [Maltase](Maltase "wikilink") ()
    -   [Lactase](Lactase "wikilink") ()
    -   [Beta-galactosidase](Beta-galactosidase "wikilink") ()
    -   [Hyaluronidase](Hyaluronidase "wikilink") ()



### [:Category:EC 3.3](:Category:EC_3.3 "wikilink") (act on [ether](ether "wikilink") bonds)

-   **[:Category:EC 3.3](:Category:EC_3.3 "wikilink")**
-   [Adenosylmethionine hydrolase](Adenosylmethionine_hydrolase "wikilink")
-   [S-adenosyl-L-homocysteine hydrolase](S-adenosyl-L-homocysteine_hydrolase "wikilink")
-   [Alkenylglycerophosphocholine hydrolase](Alkenylglycerophosphocholine_hydrolase "wikilink")
-   [Alkenylglycerophosphoethanolamine hydrolase](Alkenylglycerophosphoethanolamine_hydrolase "wikilink")
-   [Cholesterol-5,6-oxide hydrolase](Cholesterol-5,6-oxide_hydrolase "wikilink")
-   [Hepoxilin-epoxide hydrolase](Hepoxilin-epoxide_hydrolase "wikilink")
-   [Isochorismatase](Isochorismatase "wikilink")
-   [Leukotriene-A4 hydrolase](Leukotriene-A4_hydrolase "wikilink")
-   [Limonene-1,2-epoxide hydrolase](Limonene-1,2-epoxide_hydrolase "wikilink")
-   [Microsomal epoxide hydrolase](Microsomal_epoxide_hydrolase "wikilink")
-   [Trans-epoxysuccinate hydrolase](Trans-epoxysuccinate_hydrolase "wikilink")

### [:Category:EC 3.4](:Category:EC_3.4 "wikilink") (act on [peptide bonds](peptide_bond "wikilink") - [Peptidase](Peptidase "wikilink"))

-   **[:Category:EC 3.4.11](:Category:EC_3.4.11 "wikilink")**
    -   [Alanine aminopeptidase](Alanine_aminopeptidase "wikilink")
-   **[:Category:EC 3.4.15](:Category:EC_3.4.15 "wikilink")**
    -   [Angiotensin converting enzyme](Angiotensin_converting_enzyme "wikilink")
-   **[:Category:EC 3.4.21](:Category:EC_3.4.21 "wikilink")**
    -   [Serine protease](Serine_protease "wikilink")
    -   [Chymotrypsin](Chymotrypsin "wikilink") ()
    -   [Trypsin](Trypsin "wikilink") ()
    -   [Thrombin](Thrombin "wikilink") ()
    -   [Factor X](Factor_X "wikilink") ()
    -   [Plasmin](Plasmin "wikilink") ()
    -   [Acrosin](Acrosin "wikilink") ()
    -   [Factor VII](Factor_VII "wikilink") ()
    -   [Factor IX](Factor_IX "wikilink") ()
    -   [Prolyl oligopeptidase](Prolyl_oligopeptidase "wikilink") ()
    -   [Factor XI](Factor_XI "wikilink") ()
    -   [Elastase](Elastase "wikilink") ()
    -   [Factor XII](Factor_XII "wikilink") ()
    -   [Proteinase K](Proteinase_K "wikilink") ()
    -   [Tissue plasminogen activator](Tissue_plasminogen_activator "wikilink") ()
    -   [Protein C](Protein_C "wikilink") ()
-   **[:Category:EC 3.4.22](:Category:EC_3.4.22 "wikilink")**
    -   [Separase](Separase "wikilink") ()
-   **[:Category:EC 3.4.23](:Category:EC_3.4.23 "wikilink")**
    -   [Pepsin](Pepsin "wikilink") ()
    -   [Rennet](Rennet "wikilink") ()
    -   [Renin](Renin "wikilink") ()
    -   [Trypsinogen](Trypsinogen "wikilink") () and (20/21/23/24/26)
    -   [Plasmepsin](Plasmepsin "wikilink") ()
-   **[:Category:EC 3.4.24](:Category:EC_3.4.24 "wikilink")**
    -   [Matrix metalloproteinase](Matrix_metalloproteinase "wikilink") ()
-   **[:Category:EC 3.4.25](:Category:EC_3.4.25 "wikilink")**
    -   [Metalloendopeptidase](Metalloendopeptidase "wikilink")

### [:Category:EC 3.5](:Category:EC_3.5 "wikilink") (act on carbon-nitrogen bonds, other than peptide bonds)

-   **[:Category:EC 3.5.1](:Category:EC_3.5.1 "wikilink")** (In linear amides)
    -   [Urease](Urease "wikilink") ()
-   **[:Category:EC 3.5.2](:Category:EC_3.5.2 "wikilink")** (In cyclic amides)
    -   [Beta-lactamase](Beta-lactamase "wikilink") ()
-   **[:Category:EC 3.5.3](:Category:EC_3.5.3 "wikilink")** (In linear amidines)
    -   [Arginase](Arginase "wikilink") ()
-   **[:Category:EC 3.5.4](:Category:EC_3.5.4 "wikilink")** (In cyclic amidines)
    -   [Adenosine deaminase](Adenosine_deaminase "wikilink") ()
    -   [GTP cyclohydrolase I](GTP_cyclohydrolase_I "wikilink") ()
-   **[:Category:EC 3.5.5](:Category:EC_3.5.5 "wikilink")** (In nitriles)
    -   [Nitrilase](Nitrilase "wikilink") ()

### [:Category:EC 3.6](:Category:EC_3.6 "wikilink") (act on [acid anhydrides](acid_anhydride "wikilink"))

-   **[:Category:EC 3.6.1](:Category:EC_3.6.1 "wikilink")**
    -   [Helicase](Helicase "wikilink")
    -   [DnaB helicase](DnaB_helicase "wikilink")
    -   [RecQ helicase](RecQ_helicase "wikilink")
-   **[:Category:EC 3.6.3](:Category:EC_3.6.3 "wikilink")**
    -   [ATPase](ATPase "wikilink")
    -   [NaKATPase](NaKATPase "wikilink") ()
    -   [ATP synthase](ATP_synthase "wikilink") ()

### [:Category:EC 3.7](:Category:EC_3.7 "wikilink") (act on carbon-carbon bonds)

-   [Kynureninase](Kynureninase "wikilink")

### [:Category:EC 3.8](:Category:EC_3.8 "wikilink") (act on [halide](halide "wikilink") bonds)

-   EC 3.8.1.3 [Haloacetate dehalogenase](Haloacetate_dehalogenase "wikilink")

### [:Category:EC 3.9](:Category:EC_3.9 "wikilink") (act on phosphorus-nitrogen bonds)

-   : [Phosphoamidase](Phosphoamidase "wikilink")

-   : [Protein arginine phosphatase](Protein_arginine_phosphatase "wikilink")

-   : [Phosphohistidine phosphatase](Phosphohistidine_phosphatase "wikilink")

### [:Category:EC 3.10](:Category:EC_3.10 "wikilink") (act on sulfur-nitrogen bonds)

-   : [N-sulfoglucosamine sulfohydrolase](N-sulfoglucosamine_sulfohydrolase "wikilink")

-   : [Cyclamate sulfohydrolase](Cyclamate_sulfohydrolase "wikilink")

### [:Category:EC 3.11](:Category:EC_3.11 "wikilink") (act on carbon-phosphorus bonds)

-   : [Phosphonoacetaldehyde hydrolase](Phosphonoacetaldehyde_hydrolase "wikilink")

-   : [Phosphonoacetate hydrolase](Phosphonoacetate_hydrolase "wikilink")

-   : [Phosphonopyruvate hydrolase](Phosphonopyruvate_hydrolase "wikilink")

### [:Category:EC 3.12](:Category:EC_3.12 "wikilink") (act on sulfur-sulfur bonds)

-   : [Trithionate hydrolase](Trithionate_hydrolase "wikilink")

### [:Category:EC 3.13](:Category:EC_3.13 "wikilink") (act on carbon-sulfur bonds)

-   : [UDP-sulfoquinovose synthase](UDP-sulfoquinovose_synthase "wikilink")

-   : [2'-hydroxybiphenyl-2-sulfinate desulfinase](2'-hydroxybiphenyl-2-sulfinate_desulfinase "wikilink")

-   : [3-sulfinopropanoyl-CoA desulfinase](3-sulfinopropanoyl-CoA_desulfinase "wikilink")

-   : [Carbon disulfide hydrolase](Carbon_disulfide_hydrolase "wikilink")

-   : [(CysO sulfur-carrier protein)-S-L-cysteine hydrolase]((CysO_sulfur-carrier_protein)-S-L-cysteine_hydrolase "wikilink")

-   : [Carbonyl sulfide hydrolase](Carbonyl_sulfide_hydrolase "wikilink")

-   : [S-adenosyl-L-methionine hydrolase (adenosine-forming)](S-adenosyl-L-methionine_hydrolase_(adenosine-forming) "wikilink")

## [:Category:Lyases](:Category:Lyases "wikilink") (EC 4) ([Lyase](Lyase "wikilink"))

### [:Category:EC 4.1](:Category:EC_4.1 "wikilink") (carbon-carbon [lyases](lyase "wikilink"))

-   **[:Category:EC 4.1.1](:Category:EC_4.1.1 "wikilink")**
    -   [Ornithine decarboxylase](Ornithine_decarboxylase "wikilink") ()
    -   [Uridine monophosphate synthetase](Uridine_monophosphate_synthetase "wikilink") ()
    -   [Aromatic-L-amino-acid decarboxylase](Aromatic-L-amino-acid_decarboxylase "wikilink") ()
    -   [RubisCO](RubisCO "wikilink") ()
-   **[:Category:EC 4.1.2](:Category:EC_4.1.2 "wikilink")**
    -   [Fructose-bisphosphate aldolase](Fructose-bisphosphate_aldolase "wikilink") ()

### [:Category:EC 4.2](:Category:EC_4.2 "wikilink") (carbon-oxygen [lyases](lyase "wikilink"))

-   **[:Category:EC 4.2.1](:Category:EC_4.2.1 "wikilink")**
    -   [Carbonic anhydrase](Carbonic_anhydrase "wikilink") ()
    -   [Tryptophan synthase](Tryptophan_synthase "wikilink") ()

### [:Category:EC 4.3](:Category:EC_4.3 "wikilink") (carbon-nitrogen [lyases](lyase "wikilink"))

-   **[:Category:EC 4.3.1](:Category:EC_4.3.1 "wikilink")**
    -   [Phenylalanine ammonia-lyase](Phenylalanine_ammonia-lyase "wikilink") ()

### [:Category:EC 4.4](:Category:EC_4.4 "wikilink") (carbon-sulfur [lyases](lyase "wikilink"))

-   **[:Category:EC 4.4.1](:Category:EC_4.4.1 "wikilink")**
    -   [Cystathionine gamma-lyase](Cystathionine_gamma-lyase "wikilink")
    -   [Cystathionine beta-lyase](Cystathionine_beta-lyase "wikilink")
    -   [Leukotriene C4 synthase](Leukotriene_C4_synthase "wikilink")

### [:Category:EC 4.5](:Category:EC_4.5 "wikilink") (carbon-halide [lyases](lyase "wikilink"))

-   **[:Category:EC 4.5.1](:Category:EC_4.5.1 "wikilink")**
    -   [Dichloromethane dehalogenase](Dichloromethane_dehalogenase "wikilink")
    -   [Halohydrin dehalogenase](Halohydrin_dehalogenase "wikilink")

### [:Category:EC 4.6](:Category:EC_4.6 "wikilink") (phosphorus-oxygen [lyases](lyase "wikilink"))

-   **[:Category:EC 4.6.1](:Category:EC_4.6.1 "wikilink")**
    -   [Adenylate cyclase](Adenylate_cyclase "wikilink") ()
    -   [Guanylate cyclase](Guanylate_cyclase "wikilink") ()

## [:Category:Isomerases](:Category:Isomerases "wikilink") (EC 5) ([Isomerase](Isomerase "wikilink"))

### [:Category:EC 5.1](:Category:EC_5.1 "wikilink") (racemases and epimerases)

-   **[:Category:EC 5.1.1](:Category:EC_5.1.1 "wikilink")**
-   [Amino-acid racemase](Amino-acid_racemase "wikilink"): [Phenylalanine racemase (ATP-hydrolysing)](Phenylalanine_racemase_(ATP-hydrolysing) "wikilink")
-   [Serine racemase](Serine_racemase "wikilink")
-   **[:Category:EC 5.1.2](:Category:EC_5.1.2 "wikilink")**
-   [Mandelate racemase](Mandelate_racemase "wikilink")
-   **[:Category:EC 5.1.3](:Category:EC_5.1.3 "wikilink")**
-   [UDP-glucose 4-epimerase](UDP-glucose_4-epimerase "wikilink")
-   **[:Category:EC 5.1.99](:Category:EC_5.1.99 "wikilink")**
-   [Methylmalonyl CoA epimerase](Methylmalonyl_CoA_epimerase "wikilink")

### [:Category:EC 5.2](:Category:EC_5.2 "wikilink") (cis-trans-isomerases)

-   **[:Category:EC 5.2](:Category:EC_5.2 "wikilink")**
-   [FKBP](FKBP "wikilink"): [FKBP1A](FKBP1A "wikilink")
-   [FKBP1B](FKBP1B "wikilink")
-   [FKBP2](FKBP2 "wikilink")
-   [FKBP3](FKBP3 "wikilink")
-   [FKBP4](FKBP4 "wikilink")
-   [FKBP5](FKBP5 "wikilink")
-   [FKBP6](FKBP6 "wikilink")
-   [FKBP8](FKBP8 "wikilink")
-   [FKBP9](FKBP9 "wikilink")
-   [FKBP10](FKBP10 "wikilink")
-   [FKBPL](FKBPL "wikilink")
-   [Cyclophilin](Cyclophilin "wikilink")
-   [Parvulin](Parvulin "wikilink")
-   [Prolyl isomerase](Prolyl_isomerase "wikilink")
-   [2-chloro-4-carboxymethylenebut-2-en-1,4-olide isomerase](2-chloro-4-carboxymethylenebut-2-en-1,4-olide_isomerase "wikilink")
-   [Beta-carotene isomerase](Beta-carotene_isomerase "wikilink")
-   [Farnesol 2-isomerase](Farnesol_2-isomerase "wikilink")
-   [Furylfuramide isomerase](Furylfuramide_isomerase "wikilink")
-   [Linoleate isomerase](Linoleate_isomerase "wikilink")
-   [Maleate isomerase](Maleate_isomerase "wikilink")
-   [Maleylacetoacetate isomerase](Maleylacetoacetate_isomerase "wikilink")
-   [Maleylpyruvate isomerase](Maleylpyruvate_isomerase "wikilink")
-   [Parvulin](Parvulin "wikilink")
-   [Photoisomerase](Photoisomerase "wikilink")
-   [Prolycopene isomerase](Prolycopene_isomerase "wikilink")
-   [Prolyl isomerase](Prolyl_isomerase "wikilink")
-   [Retinal isomerase](Retinal_isomerase "wikilink")
-   [Retinol isomerase](Retinol_isomerase "wikilink")
-   [Zeta-carotene isomerase](Zeta-carotene_isomerase "wikilink")

### [:Category:EC 5.3](:Category:EC_5.3 "wikilink") ([intramolecular](Intramolecular_reaction "wikilink") [oxidoreductases](oxidoreductase "wikilink"))

-   **[:Category:EC 5.3.3](:Category:EC_5.3.3 "wikilink")**
    -   [Enoyl CoA isomerase](Enoyl_CoA_isomerase "wikilink") ()
-   **[:Category:EC 5.3.4](:Category:EC_5.3.4 "wikilink")**
    -   [Protein disulfide isomerase](Protein_disulfide_isomerase "wikilink") ()

### [:Category:EC 5.4](:Category:EC_5.4 "wikilink") (intramolecular [transferases](transferase "wikilink") -- [mutases](mutase "wikilink"))

-   **[:Category:EC 5.4.2](:Category:EC_5.4.2 "wikilink")**
    -   [Phosphoglucomutase](Phosphoglucomutase "wikilink") ()

### [:Category:EC 5.5](:Category:EC_5.5 "wikilink") (intramolecular [lyases](lyase "wikilink"))


### [:Category:EC 5.99](:Category:EC_5.99 "wikilink") (other isomerases)

-   **[:Category:EC 5.99.1](:Category:EC_5.99.1 "wikilink")**
    -   [Topoisomerase](Topoisomerase "wikilink") (type I: , type II: )

## [:Category:Ligases](:Category:Ligases "wikilink") (EC 6) ([Ligase](Ligase "wikilink"))

### [:Category:EC 6.1](:Category:EC_6.1 "wikilink") (form carbon-oxygen bonds)

[6-carboxytetrahydropterin synthase](6-carboxytetrahydropterin_synthase "wikilink")

-   **[:Category:EC 6.1.1](:Category:EC_6.1.1 "wikilink")**
    -   [FARSB](FARSB "wikilink") ()

### [:Category:EC 6.2](:Category:EC_6.2 "wikilink") (form carbon-sulfur bonds)

-   : [Acetate--CoA ligase](Acetate--CoA_ligase "wikilink")

-   : [Medium-chain acyl-CoA ligase](Medium-chain_acyl-CoA_ligase "wikilink")

-   : [Long-chain-fatty-acid-CoA ligase](Long-chain-fatty-acid-CoA_ligase "wikilink")

-   : [Succinate-CoA ligase (GDP-forming)](Succinate-CoA_ligase_(GDP-forming) "wikilink")

-   : [Succinate-CoA ligase (ADP-forming)](Succinate-CoA_ligase_(ADP-forming) "wikilink")

-   : [Glutarate-CoA ligase](Glutarate-CoA_ligase "wikilink")

-   : [Cholate-CoA ligase](Cholate-CoA_ligase "wikilink")

-   : [Oxalate-CoA ligase](Oxalate-CoA_ligase "wikilink")

-   : [Malate-CoA ligase](Malate-CoA_ligase "wikilink")

-   : [Acid-CoA ligase (GDP-forming)](Acid-CoA_ligase_(GDP-forming) "wikilink")

-   : [Biotin-CoA ligase](Biotin-CoA_ligase "wikilink")

-   : [4-coumarate-CoA ligase](4-coumarate-CoA_ligase "wikilink")

-   : [Acetate-CoA ligase (ADP-forming)](Acetate-CoA_ligase_(ADP-forming) "wikilink")

-   : [6-carboxyhexanoate-CoA ligase](6-carboxyhexanoate-CoA_ligase "wikilink")

-   : [Arachidonate-CoA ligase](Arachidonate-CoA_ligase "wikilink")

-   : [Acetoacetate-CoA ligase](Acetoacetate-CoA_ligase "wikilink")

-   : [Propionate-CoA ligase](Propionate-CoA_ligase "wikilink")

-   : [Citrate-CoA ligase](Citrate-CoA_ligase "wikilink")

-   : [Long-chain-fatty-acid-luciferin-component ligase](Long-chain-fatty-acid-luciferin-component_ligase "wikilink")

-   : [Long-chain-fatty-acid-(acyl-carrier-protein) ligase](Long-chain-fatty-acid-(acyl-carrier-protein)_ligase "wikilink")

-   : [Transferred entry: 6.2.1.30](Transferred_entry:_6.2.1.30 "wikilink")

-   : [(citrate (pro-3S)-lyase) ligase]((citrate_(pro-3S)-lyase)_ligase "wikilink")

-   : [Dicarboxylate-CoA ligase](Dicarboxylate-CoA_ligase "wikilink")

-   : [Phytanate-CoA ligase](Phytanate-CoA_ligase "wikilink")

-   : [Benzoate-CoA ligase](Benzoate-CoA_ligase "wikilink")

-   : [o-succinylbenzoate-CoA ligase](o-succinylbenzoate-CoA_ligase "wikilink")

-   : [4-hydroxybenzoate-CoA ligase](4-hydroxybenzoate-CoA_ligase "wikilink")

-   : [3a,7a-dihydroxy-5b-cholestanate-CoA ligase](3a,7a-dihydroxy-5b-cholestanate-CoA_ligase "wikilink")

-   : [Transferred entry: 6.2.1.7](Transferred_entry:_6.2.1.7 "wikilink")

-   : [Phenylacetate-CoA ligase](Phenylacetate-CoA_ligase "wikilink")

-   : [2-furoate-CoA ligase](2-furoate-CoA_ligase "wikilink")

-   : [Anthranilate-CoA ligase](Anthranilate-CoA_ligase "wikilink")

-   : [4-chlorobenzoate-CoA ligase](4-chlorobenzoate-CoA_ligase "wikilink")

-   : [Trans-feruloyl-CoA synthase](Trans-feruloyl-CoA_synthase "wikilink")

-   : [ACP-SH:acetate ligase](ACP-SH:acetate_ligase "wikilink")

-   : [3-hydroxypropionyl-CoA synthase](3-hydroxypropionyl-CoA_synthase "wikilink")

-   : [3-hydroxybenzoate—CoA ligase](3-hydroxybenzoate—CoA_ligase "wikilink")

-   : [(2,2,3-trimethyl-5-oxocyclopent-3-enyl)acetyl-CoA synthase]((2,2,3-trimethyl-5-oxocyclopent-3-enyl)acetyl-CoA_synthase "wikilink")

-   : [(butirosin acyl-carrier protein)—L-glutamate ligase]((butirosin_acyl-carrier_protein)—L-glutamate_ligase "wikilink")

-   : [4-hydroxybutyrate-CoA ligase](4-hydroxybutyrate-CoA_ligase "wikilink")

-   : [3-((3aS,4S,7aS)-7a-methyl-1,5-dioxo-octahydro-1H-inden-4-yl)propanoate-CoA ligase](3-((3aS,4S,7aS)-7a-methyl-1,5-dioxo-octahydro-1H-inden-4-yl)propanoate-CoA_ligase "wikilink")

-   : [3-oxocholest-4-en-26-oate-CoA ligase](3-oxocholest-4-en-26-oate-CoA_ligase "wikilink")

-   : [2-hydroxy-7-methoxy-5-methyl-1-naphthoate-CoA ligase](2-hydroxy-7-methoxy-5-methyl-1-naphthoate-CoA_ligase "wikilink")

-   : [3-(methylthio)propionyl-CoA ligase](3-(methylthio)propionyl-CoA_ligase "wikilink")

-   : [E1 ubiquitin-activating enzyme](E1_ubiquitin-activating_enzyme "wikilink")

-   : [L-allo-isoleucine--holo-CmaA peptidyl-carrier protein ligase](L-allo-isoleucine--holo-CmaA_peptidyl-carrier_protein_ligase "wikilink")

-   : [Medium-chain-fatty-acid-(acyl-carrier-protein) ligase](Medium-chain-fatty-acid-(acyl-carrier-protein)_ligase "wikilink")

-   : [Carnitine-CoA ligase](Carnitine-CoA_ligase "wikilink")

-   : [Long-chain fatty acid adenylyltransferase FadD28](Long-chain_fatty_acid_adenylyltransferase_FadD28 "wikilink")

-   : [4-hydroxybenzoate adenylyltransferase FadD22](4-hydroxybenzoate_adenylyltransferase_FadD22 "wikilink")

-   : [4-hydroxyphenylalkanoate adenylyltransferase FadD29](4-hydroxyphenylalkanoate_adenylyltransferase_FadD29 "wikilink")

-   : [L-firefly luciferin-CoA ligase](L-firefly_luciferin-CoA_ligase "wikilink")

-   : [L-proline-L-prolyl-carrier protein ligase](L-proline-L-prolyl-carrier_protein_ligase "wikilink")

-   : [D-alanine-D-alanyl-carrier protein ligase](D-alanine-D-alanyl-carrier_protein_ligase "wikilink")

-   : [E1 SAMP-activating enzyme](E1_SAMP-activating_enzyme "wikilink")

### [:Category:EC 6.3](:Category:EC_6.3 "wikilink") (form carbon-nitrogen bonds)

-   [Glutamine synthetase](Glutamine_synthetase "wikilink") ()
-   [Argininosuccinate synthetase](Argininosuccinate_synthetase "wikilink") ()
-   [CTP synthase](CTP_synthase "wikilink") ()

### [:Category:EC 6.4](:Category:EC_6.4 "wikilink") (form carbon-carbon bonds)

-   [Pyruvate carboxylase](Pyruvate_carboxylase "wikilink") ()
-   [Acetyl-CoA carboxylase](Acetyl-CoA_carboxylase "wikilink") ()

### [:Category:EC 6.5](:Category:EC_6.5 "wikilink") (form [phosphoric ester](phosphoric_ester "wikilink") bonds)

[DNA ligase](DNA_ligase "wikilink") ()

### [:Category:EC 6.6](:Category:EC_6.6 "wikilink") (form nitrogen-metal bonds)